# coding: utf8

from __future__ import print_function

import evaltools as evt
from datetime import date, timedelta

obs_path = "../doc/sample_data/observations/{year}_{species}_{station}"
sim_path = ("../doc/sample_data/{model}{runtype}/J{forecastDay}/" +
            "{year}_{species}_{station}")

listing_path = "../doc/sample_data/listing"
stations = evt.utils.read_listing(listing_path, classes='all', types='all',
                                  area_coord=None)

start_date = date(2017, 6, 1)
end_date = date(2017, 6, 4)

model_list = ["ENS", "MFM"]
model_colors = {"ENS": '#CB025A', "MFM": '#004D8A'}
species = 'no2'

observations = evt.evaluator.Observations.fromTimeSeries(
    generic_file_path=obs_path.format(year="{year}", species=species,
                                      station="{station}"),
    correc_unit=1e9,
    species=species,
    start=start_date,
    end=end_date,
    stations=stations,
    forecastHorizon=4)

persistence = observations.persistenceModel()

observations = observations.subPeriod(start_date+timedelta(1), end_date)

objs = {}
daily_objs = {}
fh = 4
for model in model_list:
    generic_file_path = sim_path.format(
        model=model, runtype='forecast', forecastDay='{forecastDay}',
        year='{year}', species=species, station='{station}')
    stations_idx = observations.stations.index
    simulations = evt.evaluator.Simulations.fromTimeSeries(
        generic_file_path=generic_file_path,
        stationsIdx=stations_idx,
        forecastHorizon=fh,
        correc_unit=1,
        species=species,
        model=model,
        start=start_date+timedelta(1),
        end=end_date)
    objs[model] = evt.evaluator.Evaluator(observations, simulations,
                                          color=model_colors[model])
    daily_objs[model] = objs[model].dailyMax()

print("medianStationScores")
evt.plotting.plot_medianStationScores(
    list(objs.values())+[persistence],
    score_list=['RMSE'],
    title="Median station scores as a function of the forecast term\n",
    file_formats=['png'])
